@@ -1,15 +1,15 @@
 #if PERL_VERSION == 10 && PERL_SUBVERSION == 0
 #include "token_info-5.10.0.h"
 #elif PERL_VERSION == 10 && PERL_SUBVERSION == 1
-#include "token_info-5.10.1.h"
+#include "token_info-5.10.0.h"
 #elif PERL_VERSION == 11 && PERL_SUBVERSION == 0
 #include "token_info-5.11.0.h"
 #elif PERL_VERSION == 11 && PERL_SUBVERSION == 1
-#include "token_info-5.11.1.h"
+#include "token_info-5.11.0.h"
 #elif PERL_VERSION == 11 && PERL_SUBVERSION == 2
 #include "token_info-5.11.2.h"
 #elif PERL_VERSION == 11 && PERL_SUBVERSION == 3
-#include "token_info-5.11.3.h"
+#include "token_info-5.11.2.h"
 #elif PERL_VERSION == 11 && PERL_SUBVERSION == 4
 #include "token_info-5.11.4.h"
 #elif PERL_VERSION == 11 && PERL_SUBVERSION == 5
@@ -17,29 +17,25 @@
 #elif PERL_VERSION == 12 && PERL_SUBVERSION == 0
 #include "token_info-5.12.0.h"
 #elif PERL_VERSION == 12 && PERL_SUBVERSION == 1
-#include "token_info-5.12.1.h"
+#include "token_info-5.12.0.h"
 #elif PERL_VERSION == 12 && PERL_SUBVERSION == 2
-#include "token_info-5.12.2.h"
+#include "token_info-5.12.0.h"
 #elif PERL_VERSION == 12 && PERL_SUBVERSION == 3
-#include "token_info-5.12.3.h"
+#include "token_info-5.12.0.h"
 #elif PERL_VERSION == 12 && PERL_SUBVERSION == 4
-#include "token_info-5.12.4.h"
+#include "token_info-5.12.0.h"
 #elif PERL_VERSION == 12 && PERL_SUBVERSION == 5
-#include "token_info-5.12.5.h"
+#include "token_info-5.12.0.h"
 #elif PERL_VERSION == 13 && PERL_SUBVERSION == 0
 #include "token_info-5.13.0.h"
 #elif PERL_VERSION == 13 && PERL_SUBVERSION == 1
-#include "token_info-5.13.1.h"
-#elif PERL_VERSION == 13 && PERL_SUBVERSION == 10
-#include "token_info-5.13.10.h"
-#elif PERL_VERSION == 13 && PERL_SUBVERSION == 11
-#include "token_info-5.13.11.h"
+#include "token_info-5.13.0.h"
 #elif PERL_VERSION == 13 && PERL_SUBVERSION == 2
 #include "token_info-5.13.2.h"
 #elif PERL_VERSION == 13 && PERL_SUBVERSION == 3
-#include "token_info-5.13.3.h"
+#include "token_info-5.13.2.h"
 #elif PERL_VERSION == 13 && PERL_SUBVERSION == 4
-#include "token_info-5.13.4.h"
+#include "token_info-5.13.2.h"
 #elif PERL_VERSION == 13 && PERL_SUBVERSION == 5
 #include "token_info-5.13.5.h"
 #elif PERL_VERSION == 13 && PERL_SUBVERSION == 6
@@ -49,17 +45,21 @@
 #elif PERL_VERSION == 13 && PERL_SUBVERSION == 8
 #include "token_info-5.13.8.h"
 #elif PERL_VERSION == 13 && PERL_SUBVERSION == 9
-#include "token_info-5.13.9.h"
+#include "token_info-5.13.8.h"
+#elif PERL_VERSION == 13 && PERL_SUBVERSION == 10
+#include "token_info-5.13.10.h"
+#elif PERL_VERSION == 13 && PERL_SUBVERSION == 11
+#include "token_info-5.13.10.h"
 #elif PERL_VERSION == 14 && PERL_SUBVERSION == 0
 #include "token_info-5.14.0.h"
 #elif PERL_VERSION == 14 && PERL_SUBVERSION == 1
-#include "token_info-5.14.1.h"
+#include "token_info-5.14.0.h"
 #elif PERL_VERSION == 14 && PERL_SUBVERSION == 2
-#include "token_info-5.14.2.h"
+#include "token_info-5.14.0.h"
 #elif PERL_VERSION == 14 && PERL_SUBVERSION == 3
-#include "token_info-5.14.3.h"
+#include "token_info-5.14.0.h"
 #elif PERL_VERSION == 14 && PERL_SUBVERSION == 4
-#include "token_info-5.14.4.h"
+#include "token_info-5.14.0.h"
 #elif PERL_VERSION == 15 && PERL_SUBVERSION == 0
 #include "token_info-5.15.0.h"
 #elif PERL_VERSION == 15 && PERL_SUBVERSION == 1
@@ -67,35 +67,31 @@
 #elif PERL_VERSION == 15 && PERL_SUBVERSION == 2
 #include "token_info-5.15.2.h"
 #elif PERL_VERSION == 15 && PERL_SUBVERSION == 3
-#include "token_info-5.15.3.h"
+#include "token_info-5.15.2.h"
 #elif PERL_VERSION == 15 && PERL_SUBVERSION == 4
-#include "token_info-5.15.4.h"
+#include "token_info-5.15.2.h"
 #elif PERL_VERSION == 15 && PERL_SUBVERSION == 5
-#include "token_info-5.15.5.h"
+#include "token_info-5.15.2.h"
 #elif PERL_VERSION == 15 && PERL_SUBVERSION == 6
-#include "token_info-5.15.6.h"
+#include "token_info-5.15.2.h"
 #elif PERL_VERSION == 15 && PERL_SUBVERSION == 7
 #include "token_info-5.15.7.h"
 #elif PERL_VERSION == 15 && PERL_SUBVERSION == 8
-#include "token_info-5.15.8.h"
+#include "token_info-5.15.7.h"
 #elif PERL_VERSION == 15 && PERL_SUBVERSION == 9
-#include "token_info-5.15.9.h"
+#include "token_info-5.15.7.h"
 #elif PERL_VERSION == 16 && PERL_SUBVERSION == 0
 #include "token_info-5.16.0.h"
 #elif PERL_VERSION == 16 && PERL_SUBVERSION == 1
-#include "token_info-5.16.1.h"
+#include "token_info-5.16.0.h"
 #elif PERL_VERSION == 16 && PERL_SUBVERSION == 2
-#include "token_info-5.16.2.h"
+#include "token_info-5.16.0.h"
 #elif PERL_VERSION == 16 && PERL_SUBVERSION == 3
-#include "token_info-5.16.3.h"
+#include "token_info-5.16.0.h"
 #elif PERL_VERSION == 17 && PERL_SUBVERSION == 0
 #include "token_info-5.17.0.h"
 #elif PERL_VERSION == 17 && PERL_SUBVERSION == 1
 #include "token_info-5.17.1.h"
-#elif PERL_VERSION == 17 && PERL_SUBVERSION == 10
-#include "token_info-5.17.10.h"
-#elif PERL_VERSION == 17 && PERL_SUBVERSION == 11
-#include "token_info-5.17.11.h"
 #elif PERL_VERSION == 17 && PERL_SUBVERSION == 2
 #include "token_info-5.17.2.h"
 #elif PERL_VERSION == 17 && PERL_SUBVERSION == 3
@@ -107,37 +103,47 @@
 #elif PERL_VERSION == 17 && PERL_SUBVERSION == 6
 #include "token_info-5.17.6.h"
 #elif PERL_VERSION == 17 && PERL_SUBVERSION == 7
-#include "token_info-5.17.7.h"
+#include "token_info-5.17.6.h"
 #elif PERL_VERSION == 17 && PERL_SUBVERSION == 8
-#include "token_info-5.17.8.h"
+#include "token_info-5.17.6.h"
 #elif PERL_VERSION == 17 && PERL_SUBVERSION == 9
-#include "token_info-5.17.9.h"
+#include "token_info-5.17.6.h"
+#elif PERL_VERSION == 17 && PERL_SUBVERSION == 10
+#include "token_info-5.17.10.h"
+#elif PERL_VERSION == 17 && PERL_SUBVERSION == 11
+#include "token_info-5.17.10.h"
 #elif PERL_VERSION == 18 && PERL_SUBVERSION == 0
 #include "token_info-5.18.0.h"
 #elif PERL_VERSION == 18 && PERL_SUBVERSION == 1
-#include "token_info-5.18.1.h"
+#include "token_info-5.18.0.h"
 #elif PERL_VERSION == 18 && PERL_SUBVERSION == 2
-#include "token_info-5.18.2.h"
+#include "token_info-5.18.0.h"
 #elif PERL_VERSION == 19 && PERL_SUBVERSION == 0
 #include "token_info-5.19.0.h"
 #elif PERL_VERSION == 19 && PERL_SUBVERSION == 1
 #include "token_info-5.19.1.h"
-#elif PERL_VERSION == 19 && PERL_SUBVERSION == 10
-#include "token_info-5.19.10.h"
 #elif PERL_VERSION == 19 && PERL_SUBVERSION == 2
-#include "token_info-5.19.2.h"
+#include "token_info-5.19.1.h"
 #elif PERL_VERSION == 19 && PERL_SUBVERSION == 3
-#include "token_info-5.19.3.h"
+#include "token_info-5.19.1.h"
 #elif PERL_VERSION == 19 && PERL_SUBVERSION == 4
 #include "token_info-5.19.4.h"
 #elif PERL_VERSION == 19 && PERL_SUBVERSION == 5
 #include "token_info-5.19.5.h"
 #elif PERL_VERSION == 19 && PERL_SUBVERSION == 6
-#include "token_info-5.19.6.h"
+#include "token_info-5.19.5.h"
 #elif PERL_VERSION == 19 && PERL_SUBVERSION == 7
 #include "token_info-5.19.7.h"
 #elif PERL_VERSION == 19 && PERL_SUBVERSION == 8
 #include "token_info-5.19.8.h"
 #elif PERL_VERSION == 19 && PERL_SUBVERSION == 9
 #include "token_info-5.19.9.h"
+#elif PERL_VERSION == 19 && PERL_SUBVERSION == 10
+#include "token_info-5.19.9.h"
+#elif PERL_VERSION == 19 && PERL_SUBVERSION == 11
+#include "token_info-5.19.9.h"
+#elif PERL_VERSION > 19 || (PERL_VERSION == 19 && PERL_SUBVERSION > 11)
+#include "token_info-latest.h"
+#else
+#error "No support for this perl version"
 #endif
